@@ -39,7 +39,6 @@ class CoherenceAnalyzer(BaseAnalyzer):
         Examples
         --------
         >>> import nitime.timeseries as ts
-        >>> np.set_printoptions(precision=4)  # for doctesting
         >>> t1 = ts.TimeSeries(data = np.arange(0,1024,1).reshape(2,512),
         ...                                 sampling_rate=np.pi)
         >>> c1 = CoherenceAnalyzer(t1)
@@ -48,11 +47,11 @@ class CoherenceAnalyzer(BaseAnalyzer):
         >>> c1.method['this_method']
         'welch'
         >>> c1.coherence[0,1]
-        array([ 0.9024,  0.9027,  0.9652,  0.9433,  0.9297,  0.9213,  0.9161,
-                0.9126,  0.9102,  0.9085,  0.9072,  0.9063,  0.9055,  0.905 ,
-                0.9045,  0.9041,  0.9038,  0.9036,  0.9034,  0.9032,  0.9031,
-                0.9029,  0.9028,  0.9027,  0.9027,  0.9026,  0.9026,  0.9025,
-                0.9025,  0.9025,  0.9025,  0.9026,  1.    ])
+        array([0.9024, 0.9027, 0.9652, 0.9433, 0.9297, 0.9213, 0.9161, 0.9126,
+               0.9102, 0.9085, 0.9072, 0.9063, 0.9055, 0.905 , 0.9045, 0.9041,
+               0.9038, 0.9036, 0.9034, 0.9032, 0.9031, 0.9029, 0.9028, 0.9027,
+               0.9027, 0.9026, 0.9026, 0.9025, 0.9025, 0.9025, 0.9025, 0.9026,
+               1.    ])
         >>> c1.phase[0,1]
         array([ 0.    , -0.035 , -0.4839, -0.4073, -0.3373, -0.2828, -0.241 ,
                -0.2085, -0.1826, -0.1615, -0.144 , -0.1292, -0.1164, -0.1054,
