@@ -43,7 +43,6 @@ class SpectralAnalyzer(BaseAnalyzer):
 
         Examples
         --------
-        >>> np.set_printoptions(precision=4)  # for doctesting
         >>> t1 = ts.TimeSeries(data = np.arange(0,1024,1).reshape(2,512),
         ... sampling_rate=np.pi)
         >>> s1 = SpectralAnalyzer(t1)
@@ -53,13 +52,13 @@ class SpectralAnalyzer(BaseAnalyzer):
         3.1415926535... Hz
         >>> f,s = s1.psd
         >>> f
-        array([ 0.    ,  0.0491,  0.0982,  0.1473,  0.1963,  0.2454,  0.2945,
-                0.3436,  0.3927,  0.4418,  0.4909,  0.54  ,  0.589 ,  0.6381,
-                0.6872,  0.7363,  0.7854,  0.8345,  0.8836,  0.9327,  0.9817,
-                1.0308,  1.0799,  1.129 ,  1.1781,  1.2272,  1.2763,  1.3254,
-                1.3744,  1.4235,  1.4726,  1.5217,  1.5708])
+        array([0.    , 0.0491, 0.0982, 0.1473, 0.1963, 0.2454, 0.2945, 0.3436,
+               0.3927, 0.4418, 0.4909, 0.54  , 0.589 , 0.6381, 0.6872, 0.7363,
+               0.7854, 0.8345, 0.8836, 0.9327, 0.9817, 1.0308, 1.0799, 1.129 ,
+               1.1781, 1.2272, 1.2763, 1.3254, 1.3744, 1.4235, 1.4726, 1.5217,
+               1.5708])
         >>> s[0,0]   # doctest: +ELLIPSIS
-        1128276.92538360...
+        1128276.9253836009
         """
         BaseAnalyzer.__init__(self, input)
 
