@@ -192,13 +192,16 @@ class TimeArray(np.ndarray, TimeInterface):
         time._conversion_factor = time_unit_conversion[time_unit]
         return time
 
-    def __array_wrap__(self, out_arr, context=None):
+    def __array_wrap__(self, out_arr, context=None, return_scalar=False):
         # When doing comparisons between TimeArrays, make sure that you return
         # a boolean array, not a time array:
         if out_arr.dtype == bool:
-            return np.asarray(out_arr)
+            ret = np.asarray(out_arr)
+            if return_scalar:
+                ret = ret[()]
+            return ret
         else:
-            return np.ndarray.__array_wrap__(self, out_arr, context)
+            return np.ndarray.__array_wrap__(self, out_arr, context, return_scalar)
 
     def __array_finalize__(self, obj):
         """XXX """
@@ -691,13 +694,16 @@ class UniformTime(np.ndarray, TimeInterface):
 
         return time
 
-    def __array_wrap__(self, out_arr, context=None):
+    def __array_wrap__(self, out_arr, context=None, return_scalar=False):
         # When doing comparisons between UniformTime, make sure that you return
         # a boolean array, not a time array:
         if out_arr.dtype == bool:
-            return np.asarray(out_arr)
+            ret = np.asarray(out_arr)
+            if return_scalar:
+                ret = ret[()]
+            return ret
         else:
-            return np.ndarray.__array_wrap__(self, out_arr, context)
+            return np.ndarray.__array_wrap__(self, out_arr, context, return_scalar)
 
     def __array_finalize__(self, obj):
         """XXX """
@@ -1101,7 +1107,7 @@ class TimeSeries(TimeSeriesBase):
 
         >>> ts = TimeSeries([1,2,3],sampling_interval=0.25)
         >>> ts.time
-        UniformTime([ 0.  ,  0.25,  0.5 ], time_unit='s')
+        UniformTime([0.  , 0.25, 0.5 ], time_unit='s')
         >>> ts.t0
         0.0 s
         >>> ts.sampling_rate
@@ -1111,7 +1117,7 @@ class TimeSeries(TimeSeriesBase):
 
         >>> ts = TimeSeries([1,2,3],sampling_rate=2)
         >>> ts.time
-        UniformTime([ 0. ,  0.5,  1. ], time_unit='s')
+        UniformTime([0. , 0.5, 1. ], time_unit='s')
         >>> ts.t0
         0.0 s
         >>> ts.sampling_interval
@@ -1123,7 +1129,7 @@ class TimeSeries(TimeSeriesBase):
         >>> ts.data
         array([1, 2, 3])
         >>> ts.time
-        UniformTime([ 4.25,  4.75,  5.25], time_unit='s')
+        UniformTime([4.25, 4.75, 5.25], time_unit='s')
         >>> ts.t0
         4.25 s
         >>> ts.sampling_interval
@@ -1135,7 +1141,7 @@ class TimeSeries(TimeSeriesBase):
         >>> ts.data
         array([1, 2, 3])
         >>> ts.time
-        UniformTime([ 4.25,  4.75,  5.25], time_unit='s')
+        UniformTime([4.25, 4.75, 5.25], time_unit='s')
         >>> ts.t0
         4.25 s
         >>> ts.sampling_interval
@@ -1517,7 +1523,7 @@ class Events(TimeInterface):
         if not np.iterable(time):
             time = [time]
 
-        # First initilaize the TimeArray from the time-stamps
+        # First initialize the TimeArray from the time-stamps
         self.time = TimeArray(time, time_unit=time_unit)
         self.time_unit = self.time.time_unit
 
